@@ -1,5 +1,26 @@
-.onLoad <- function(lib, pkg) {
-    require("methods", character.only = TRUE, quietly = TRUE)
+#######################################################################
+# arules - Mining Association Rules and Frequent Itemsets
+# Copyrigth (C) 2011 Michael Hahsler, Christian Buchta, 
+#			Bettina Gruen and Kurt Hornik
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+
+
+#.onLoad <- function(lib, pkg) {
+#    require("methods", character.only = TRUE, quietly = TRUE)
     
     ## FIXME: do we still need that? If yes, then the test should
     ##        be done at the level of itemMatrix
@@ -8,7 +29,7 @@
     ##setValidity("ngCMatrix",
     ##    function(object) .Call("R_valid_ngCMatrix", object),
     ##       where = .GlobalEnv)
-}
+#}
 
 
 ##**********************************************************
